aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/objective-c/GRPCClient/GRPCCall.h
diff options
context:
space:
mode:
authorGravatar Muxi Yan <mxyan@google.com>2018-10-10 16:50:12 -0700
committerGravatar Muxi Yan <mxyan@google.com>2018-10-10 16:50:12 -0700
commitefa359b02b0122c90decfbcd5e1659198b565b4e (patch)
treef6980a59547a594ca40b7fd5ea7dbb5cbf2a82d6 /src/objective-c/GRPCClient/GRPCCall.h
parent0865a6098880b91235348cb9ffe49ddbb13ebdc6 (diff)
Rename handler->responseHandler in function signature
Diffstat (limited to 'src/objective-c/GRPCClient/GRPCCall.h')
-rw-r--r--src/objective-c/GRPCClient/GRPCCall.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/objective-c/GRPCClient/GRPCCall.h b/src/objective-c/GRPCClient/GRPCCall.h
index 01d04807cc..8554860ade 100644
--- a/src/objective-c/GRPCClient/GRPCCall.h
+++ b/src/objective-c/GRPCClient/GRPCCall.h
@@ -221,18 +221,18 @@ extern id const kGRPCTrailersKey;
/**
* Designated initializer for a call.
* \param requestOptions Protobuf generated parameters for the call.
* \param handler The object to which responses should be issed.
* \param callOptions Options for the call.
*/
- (instancetype)initWithRequestOptions:(GRPCRequestOptions *)requestOptions
- handler:(id<GRPCResponseHandler>)handler
+ responseHandler:(id<GRPCResponseHandler>)responseHandler
callOptions:(GRPCCallOptions *)callOptions NS_DESIGNATED_INITIALIZER;
/**
* Convenience initializer for a call that uses default call options (see GRPCCallOptions.m for
* the default options).
*/
- (instancetype)initWithRequestOptions:(GRPCRequestOptions *)requestOptions
- handler:(id<GRPCResponseHandler>)handler;
+ responseHandler:(id<GRPCResponseHandler>)responseHandler;
/**
* Starts the call. Can only be called once.
@@ -221,18 +221,18 @@ extern id const kGRPCTrailersKey;
* Designated initializer for a call.
* \param requestOptions Protobuf generated parameters for the call.
- * \param handler The object to which responses should be issed.
+ * \param responseHandler The object to which responses should be issed.
* \param callOptions Options for the call.
*/